==> react-image-annotate_ns_demo-4.0.90.tgz: package/LazyBrush/BrushRegion.js <==
import _toConsumableArray from "@babel/runtime/helpers/esm/toConsumableArray";
import Brush from "@mui/icons-material/Brush";
import TrashIcon from "@mui/icons-material/Delete";
import LockIcon from "@mui/icons-material/Lock";
import LockOpenIcon from "@mui/icons-material/LockOpen";
import VisibilityIcon from "@mui/icons-material/Visibility";
import VisibilityOffIcon from "@mui/icons-material/VisibilityOff";
import * as colors from "@mui/material/colors";
import { createTheme, styled, ThemeProvider } from "@mui/material/styles";
import React from "react";
import SidebarBoxContainer from "../SidebarBoxContainer";
var theme = createTheme();
var KeyframeRow = styled("div")(function (_ref) {
  var theme = _ref.theme;
  return {
    cursor: "pointer",
    display: "flex",
    alignItems: "center",
    justifyContent: "space-between",
    padding: 8,
    fontSize: 14,
    color: colors.grey[700],
    "& .classification": {
      display: "flex",
      alignItems: "center",
      fontSize: "11px",
      justifyContent: "space-between",
      fontWeight: "bold",
      "& .series": {
        textAlign: "right",
        paddingRight: "10px",
        fontSize: "11px"
      }
    },
    "&.current": {
      backgroundColor: colors.blue[100]
    },
    "&:hover": {
      backgroundColor: colors.grey[100]
    },
    "& .time": {
      flexGrow: 1,
      fontWeight: "bold",
      "& .regionCount": {
        marginLeft: 8,
        fontWeight: "normal",
        color: colors.grey[500]
      }
    },
    "& .trash": {
      "& .icon": {
        fontSize: 18,
        color: "#005f86",
        width: "16px",
        height: "16px",
        opacity: 0.5,
        transition: "200ms opacity",
        "&:hover": {
          color: "#005f86",
          transform: "scale(1.25,1.25)"
        }
      }
    }
  };
});

var BrushRegion = function BrushRegion(_ref2) {
  var _brushLines$filter;

  var currentVideoTime = _ref2.currentVideoTime,
      setdelete_annotation = _ref2.setdelete_annotation,
      onChangeVideoTime = _ref2.onChangeVideoTime,
      setLines = _ref2.setLines,
      brushLines = _ref2.brushLines,
      delete_annotation = _ref2.delete_annotation;
  //   const keyframeTimes = brushLines
  return /*#__PURE__*/React.createElement(ThemeProvider, {
    theme: theme
  }, /*#__PURE__*/React.createElement(SidebarBoxContainer, {
    title: "Brush Region",
    subTitle: "",
    icon: /*#__PURE__*/React.createElement(Brush, {
      style: {
        color: colors.grey[700]
      }
    }),
    expandedByDefault: true
  }, brushLines === null || brushLines === void 0 ? void 0 : (_brushLines$filter = brushLines.filter(function (arr, index, self) {
    return index === self.findIndex(function (t) {
      return t.id === arr.id && arr.id;
    });
  })) === null || _brushLines$filter === void 0 ? void 0 : _brushLines$filter.map(function (t, index) {
    var _t$color, _t$popUp, _t$popUp$classificati;

    return /*#__PURE__*/React.createElement(KeyframeRow, {
      fullWidth: true,
      key: t
    }, /*#__PURE__*/React.createElement("div", {
      className: "classification"
    }, /*#__PURE__*/React.createElement("span", null, " #", index + 1), /*#__PURE__*/React.createElement("div", {
      style: {
        backgroundColor: (_t$color = t.color) === null || _t$color === void 0 ? void 0 : _t$color.replace("0.5", "1"),
        width: "10px",
        height: "10px",
        boxShadow: "0px 0px 2px rgb(0 0 0 / 40%)",
        marginRight: "4px",
        borderRadius: "5px"
      }
    }), /*#__PURE__*/React.createElement("span", null, t === null || t === void 0 ? void 0 : (_t$popUp = t.popUp) === null || _t$popUp === void 0 ? void 0 : (_t$popUp$classificati = _t$popUp.classification) === null || _t$popUp$classificati === void 0 ? void 0 : _t$popUp$classificati.label)), /*#__PURE__*/React.createElement("div", {
      className: "trash"
    }, /*#__PURE__*/React.createElement(TrashIcon, {
      onClick: function onClick(e) {
        var linessave = _toConsumableArray(brushLines);

        var filter_arr = linessave.filter(function (filters) {
          return filters.id !== t.id && filters;
        });
        setLines(filter_arr);

        var arr = _toConsumableArray(delete_annotation);

        var delete_arr = linessave.filter(function (filter) {
          return filter.id === t.id && filter;
        });
        arr.push(delete_arr);
        setdelete_annotation(arr);
      },
      className: "icon"
    }), t.isLocked ? /*#__PURE__*/React.createElement(LockIcon, {
      onClick: function onClick(e) {
        var linessave = _toConsumableArray(brushLines);

        var filter_arr = linessave.filter(function (filters) {
          if (filters.id === t.id) {
            filters.isLocked = false;
          }

          return filters;
        });
        setLines(filter_arr);
      },
      className: "icon"
    }) : /*#__PURE__*/React.createElement(LockOpenIcon, {
      onClick: function onClick(e) {
        var linessave = _toConsumableArray(brushLines);

        var filter_arr = linessave.filter(function (filters) {
          if (filters.id === t.id) {
            filters.isLocked = true;
          }

          return filters;
        });
        setLines(filter_arr);
      },
      className: "icon"
    }), t.isHide ? /*#__PURE__*/React.createElement(VisibilityOffIcon, {
      onClick: function onClick(e) {
        var linessave = _toConsumableArray(brushLines);

        var filter_arr = linessave.filter(function (filters) {
          if (filters.id === t.id) {
            filters.isHide = false;
          }

          return filters;
        });
        setLines(filter_arr);
      },
      className: "icon"
    }) : /*#__PURE__*/React.createElement(VisibilityIcon, {
      onClick: function onClick(e) {
        t.isHide = true;

        var linessave = _toConsumableArray(brushLines);

        var filter_arr = linessave.filter(function (filters) {
          if (filters.id === t.id) {
            filters.isHide = true;
          }

          return filters;
        });
        setLines(filter_arr);
      },
      className: "icon"
    })));
  })));
};

export default BrushRegion;

==> react-image-annotate_ns_demo-4.0.91.tgz: package/LazyBrush/BrushRegion.js <==
import _toConsumableArray from "@babel/runtime/helpers/esm/toConsumableArray";
import Brush from "@mui/icons-material/Brush";
import TrashIcon from "@mui/icons-material/Delete";
import LockIcon from "@mui/icons-material/Lock";
import LockOpenIcon from "@mui/icons-material/LockOpen";
import VisibilityIcon from "@mui/icons-material/Visibility";
import VisibilityOffIcon from "@mui/icons-material/VisibilityOff";
import * as colors from "@mui/material/colors";
import { createTheme, styled, ThemeProvider } from "@mui/material/styles";
import React from "react";
import SidebarBoxContainer from "../SidebarBoxContainer";
var theme = createTheme();
var KeyframeRow = styled("div")(function (_ref) {
  var theme = _ref.theme;
  return {
    cursor: "pointer",
    display: "flex",
    alignItems: "center",
    justifyContent: "space-between",
    padding: 8,
    fontSize: 14,
    color: colors.grey[700],
    // backgroundColor: colors.blue[100],
    "& .classification": {
      display: "flex",
      alignItems: "center",
      fontSize: "11px",
      justifyContent: "space-between",
      fontWeight: "bold",
      "& .series": {
        textAlign: "right",
        paddingRight: "10px",
        fontSize: "11px"
      }
    },
    "&.current": {
      backgroundColor: colors.blue[100]
    },
    "&:hover": {
      backgroundColor: colors.grey[100]
    },
    "& .time": {
      flexGrow: 1,
      fontWeight: "bold",
      "& .regionCount": {
        marginLeft: 8,
        fontWeight: "normal",
        color: colors.grey[500]
      }
    },
    "& .trash": {
      "& .icon": {
        fontSize: 18,
        color: "#005f86",
        width: "16px",
        height: "16px",
        opacity: 0.5,
        transition: "200ms opacity",
        "&:hover": {
          color: "#005f86",
          transform: "scale(1.25,1.25)"
        }
      }
    }
  };
});

var BrushRegion = function BrushRegion(_ref2) {
  var _brushLines$filter;

  var currentVideoTime = _ref2.currentVideoTime,
      setdelete_annotation = _ref2.setdelete_annotation,
      onChangeVideoTime = _ref2.onChangeVideoTime,
      setLines = _ref2.setLines,
      brushLines = _ref2.brushLines,
      delete_annotation = _ref2.delete_annotation,
      brushHighlight = _ref2.brushHighlight;
  //   const keyframeTimes = brushLines
  console.log(brushHighlight);
  return /*#__PURE__*/React.createElement(ThemeProvider, {
    theme: theme
  }, /*#__PURE__*/React.createElement(SidebarBoxContainer, {
    title: "Brush Region",
    subTitle: "",
    icon: /*#__PURE__*/React.createElement(Brush, {
      style: {
        color: colors.grey[700]
      }
    }),
    expandedByDefault: true
  }, brushLines === null || brushLines === void 0 ? void 0 : (_brushLines$filter = brushLines.filter(function (arr, index, self) {
    return index === self.findIndex(function (t) {
      return t.id === arr.id && arr.id;
    });
  })) === null || _brushLines$filter === void 0 ? void 0 : _brushLines$filter.map(function (t, index) {
    var _t$color, _t$popUp, _t$popUp$classificati;

    return /*#__PURE__*/React.createElement(KeyframeRow, {
      fullWidth: true,
      key: t,
      style: {
        backgroundColor: brushHighlight === index && "#bbdefb"
      },
      onClick: function onClick() {
        window.brushHighlighted(index);
      }
    }, /*#__PURE__*/React.createElement("div", {
      className: "classification"
    }, /*#__PURE__*/React.createElement("span", null, " #", index + 1), /*#__PURE__*/React.createElement("div", {
      style: {
        backgroundColor: (_t$color = t.color) === null || _t$color === void 0 ? void 0 : _t$color.replace("0.5", "1"),
        width: "10px",
        height: "10px",
        boxShadow: "0px 0px 2px rgb(0 0 0 / 40%)",
        marginRight: "4px",
        borderRadius: "5px"
      }
    }), /*#__PURE__*/React.createElement("span", null, t === null || t === void 0 ? void 0 : (_t$popUp = t.popUp) === null || _t$popUp === void 0 ? void 0 : (_t$popUp$classificati = _t$popUp.classification) === null || _t$popUp$classificati === void 0 ? void 0 : _t$popUp$classificati.label)), /*#__PURE__*/React.createElement("div", {
      className: "trash"
    }, /*#__PURE__*/React.createElement(TrashIcon, {
      onClick: function onClick(e) {
        var linessave = _toConsumableArray(brushLines);

        var filter_arr = linessave.filter(function (filters) {
          return filters.id !== t.id && filters;
        });
        setLines(filter_arr);

        var arr = _toConsumableArray(delete_annotation);

        var delete_arr = linessave.filter(function (filter) {
          return filter.id === t.id && filter;
        });
        arr.push(delete_arr);
        setdelete_annotation(arr);
      },
      className: "icon"
    }), t.isLocked ? /*#__PURE__*/React.createElement(LockIcon, {
      onClick: function onClick(e) {
        var linessave = _toConsumableArray(brushLines);

        var filter_arr = linessave.filter(function (filters) {
          if (filters.id === t.id) {
            filters.isLocked = false;
          }

          return filters;
        });
        setLines(filter_arr);
      },
      className: "icon"
    }) : /*#__PURE__*/React.createElement(LockOpenIcon, {
      onClick: function onClick(e) {
        var linessave = _toConsumableArray(brushLines);

        var filter_arr = linessave.filter(function (filters) {
          if (filters.id === t.id) {
            filters.isLocked = true;
          }

          return filters;
        });
        setLines(filter_arr);
      },
      className: "icon"
    }), t.isHide ? /*#__PURE__*/React.createElement(VisibilityOffIcon, {
      onClick: function onClick(e) {
        var linessave = _toConsumableArray(brushLines);

        var filter_arr = linessave.filter(function (filters) {
          if (filters.id === t.id) {
            filters.isHide = false;
          }

          return filters;
        });
        setLines(filter_arr);
      },
      className: "icon"
    }) : /*#__PURE__*/React.createElement(VisibilityIcon, {
      onClick: function onClick(e) {
        t.isHide = true;

        var linessave = _toConsumableArray(brushLines);

        var filter_arr = linessave.filter(function (filters) {
          if (filters.id === t.id) {
            filters.isHide = true;
          }

          return filters;
        });
        setLines(filter_arr);
      },
      className: "icon"
    })));
  })));
};

export default BrushRegion;
